        function getT(rr,cc){
       if(rr==1 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260506 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==1 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260506 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 29 <br>5,6,7,8,10,12,14,16,17,19,20,21,22,25,26,27,28,31,32,33,34,35,36,38,42,44,45,47,49';}
       if(rr==1 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260506 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 22 <strong>control</strong><br>0,1,2,3,4,9,11,13,15,18,23,24,29,30,37,39,40,41,43,46,48,50';}
       if(rr==8 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260506 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==8 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260506 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 29 <br>5,6,7,8,10,12,14,16,17,19,20,21,22,25,26,27,28,31,32,33,34,35,36,38,42,44,45,47,49';}
       if(rr==8 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260506 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 22 <strong>control</strong><br>0,1,2,3,4,9,11,13,15,18,23,24,29,30,37,39,40,41,43,46,48,50';}
       if(rr==18 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260506 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==18 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260506 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 29 <br>5,6,7,8,10,12,14,16,17,19,20,21,22,25,26,27,28,31,32,33,34,35,36,38,42,44,45,47,49';}
       if(rr==18 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260506 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 22 <strong>control</strong><br>0,1,2,3,4,9,11,13,15,18,23,24,29,30,37,39,40,41,43,46,48,50';}
       if(rr==24 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260506 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==24 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260506 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 29 <br>5,6,7,8,10,12,14,16,17,19,20,21,22,25,26,27,28,31,32,33,34,35,36,38,42,44,45,47,49';}
       if(rr==24 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260506 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 22 <strong>control</strong><br>0,1,2,3,4,9,11,13,15,18,23,24,29,30,37,39,40,41,43,46,48,50';}
       if(rr==44 && cc==0){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260506 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==44 && cc==1){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260506 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 29 <br>5,6,7,8,10,12,14,16,17,19,20,21,22,25,26,27,28,31,32,33,34,35,36,38,42,44,45,47,49';}
       if(rr==44 && cc==2){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260506 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 22 <strong>control</strong><br>0,1,2,3,4,9,11,13,15,18,23,24,29,30,37,39,40,41,43,46,48,50';}
       if(rr==45 && cc==0){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260506 a 12</strong> UTC HH+066 (rango:060-072)<br><strong>control +<br>EPS</strong>';}
       if(rr==45 && cc==1){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260506 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>1</strong> representante: <strong>17</strong> miembros: 29 <br>5,6,7,8,10,12,14,16,17,19,20,21,22,25,26,27,28,31,32,33,34,35,36,38,42,44,45,47,49';}
       if(rr==45 && cc==2){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260506 a 12</strong> UTC HH+066 (rango:060-072)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 22 <strong>control</strong><br>0,1,2,3,4,9,11,13,15,18,23,24,29,30,37,39,40,41,43,46,48,50';}
}
